@@ -23,7 +23,7 @@ from faculty.clients.base import BaseSchema, BaseClient
 
 
 @attrs
-class Account(object):
+class Account:
     """A user account in Faculty.
 
     Parameters
@@ -42,7 +42,7 @@ class Account(object):
 
 
 @attrs
-class _AuthenticationResponse(object):
+class _AuthenticationResponse:
     account = attrib()
 
 
@@ -56,11 +56,13 @@ class AccountClient(BaseClient):
 
     Parameters
     ----------
+    url : str
+        The URL of the account service.
     session : faculty.session.Session
-        The session to use to make requests
+        The session to use to make requests.
     """
 
-    _SERVICE_NAME = "hudson"
+    SERVICE_NAME = "hudson"
 
     def authenticated_account(self):
         """Get information on the account used to authenticate this session.
