@@ -13,7 +13,6 @@
 # limitations under the License.
 
 
-import sys
 from datetime import datetime
 from uuid import uuid4
 
@@ -517,43 +516,6 @@ def test_filter_schema_metric(
     }
 
 
-@pytest.mark.skipif(
-    sys.version_info > (3, 0),
-    reason="Marshmallow 3 does not do validation on dump",
-)
-def test_filter_schema_invalid_value_run_status():
-    filter = RunStatusFilter(ComparisonOperator.EQUAL_TO, "invalid")
-    with pytest.raises(AttributeError):
-        _FilterSchema().dump(filter)
-
-
-@pytest.mark.parametrize(
-    "filter_type",
-    [ProjectIdFilter, ExperimentIdFilter, RunIdFilter, DeletedAtFilter],
-)
-@pytest.mark.skipif(
-    sys.version_info > (3, 0),
-    reason="Marshmallow 3 does not do validation on dump",
-)
-def test_filter_schema_invalid_value_no_key(filter_type):
-    filter = filter_type(ComparisonOperator.EQUAL_TO, "invalid")
-    with pytest.raises(ValidationError):
-        _FilterSchema().dump(filter)
-
-
-@pytest.mark.parametrize(
-    "filter_type, value", [(ParamFilter, None), (MetricFilter, "invalid")]
-)
-@pytest.mark.skipif(
-    sys.version_info > (3, 0),
-    reason="Marshmallow 3 does not do validation on dump",
-)
-def test_filter_schema_invalid_value_with_key(filter_type, value):
-    filter = filter_type("key", ComparisonOperator.EQUAL_TO, value)
-    with pytest.raises(ValidationError):
-        _FilterSchema().dump(filter)
-
-
 @pytest.mark.parametrize(
     "filter_type, value",
     [
